@@ -1,4 +1,4 @@
-from math import *
+import math
 
 def rotate(pixel_coor:[int,int],degrees:int,rotate_coor:[int,int])->[int,int]:
   """
@@ -11,12 +11,12 @@ def rotate(pixel_coor:[int,int],degrees:int,rotate_coor:[int,int])->[int,int]:
   rx , ry = rotate_coor
   dx , dy = abs(px-rx), abs(py-ry)
   
-  a = degrees-atan2(dy,dx)*180/pi
-  r = sqrt(dx**2+dy**2)
+  a = degrees-math.atan2(dy,dx)*180/pi
+  r = math.sqrt(dx**2+dy**2)
 
   px , py = rx , ry
 
   for todo in range(round(r)):
-    px , py = px+sin(radians(a)) , py+cos(radians(a))
+    px , py = px+math.sin(math.radians(a)) , py+math.cos(math.radians(a))
 
   return [round(px) , round(py)]
\ No newline at end of file
